@@ -59,7 +59,8 @@ class AppConfig(ConfigBase):
             CONFIG_NODE_SERVER,
             "host"
         ],
-        default=DEFAULT_SERVER_HOST)
+        default=DEFAULT_SERVER_HOST,
+        secret=True)
 
     SERVER_PORT = IntConfigEntry(
         key_path=[
@@ -76,7 +77,7 @@ class AppConfig(ConfigBase):
             CONFIG_NODE_SERVER,
             "api_token"
         ],
-        required=True,
+        default=None,
         secret=True
     )
 
